@@ -512,31 +512,62 @@ def create_agent_specific_md_file(project_path: Path, agent: str, tracker: StepT
     """
     import importlib.resources
     import traceback
+    import sys
     from pathlib import Path
     
     try:
-        # Get the agent file template - use current working directory
+        # Try multiple methods to find the template file
+        
+        # Method 1: Look in the current working directory (where templates should be after extraction during init)
         templates_root_dir = Path.cwd() / "templates"
-
-        if not templates_root_dir.exists():
-            error_msg = f"Templates not found at {templates_root_dir}"
-            if tracker:
-                tracker.error(f"agent-md-{agent}", error_msg)
-            else:
-                console.print(f"[red]Error:[/red] {error_msg}")
-            return
-
-        # Read the agent template
         agent_template_path = templates_root_dir / "agent-file-template.md"
-        if not agent_template_path.exists():
-            error_msg = f"Agent template not found: {agent_template_path}"
-            if tracker:
-                tracker.error(f"agent-md-{agent}", error_msg)
-            else:
-                console.print(f"[red]Error:[/red] {error_msg}")
-            return
-
-        template_content = agent_template_path.read_text(encoding='utf-8')
+        
+        # Check if the template exists in the current working directory templates
+        if agent_template_path.exists():
+            template_content = agent_template_path.read_text(encoding='utf-8')
+            console.print(f"[green]Debug:[/green] Found template at: {agent_template_path}")
+        else:
+            # Method 2: Use importlib.resources to access the template from the package
+            # This works when the package is installed with templates included as package data
+            try:
+                # Try to use importlib.resources to access the template from our package
+                if sys.version_info >= (3, 9):
+                    # Python 3.9+ has files() method
+                    from importlib.resources import files
+                    template_path_obj = files('blueprint_cli').joinpath('templates', 'agent-file-template.md')
+                    with template_path_obj.open('r', encoding='utf-8') as f:
+                        template_content = f.read()
+                    console.print(f"[green]Debug:[/green] Found template using importlib.resources.files")
+                else:
+                    # For older Python versions, use read_text
+                    try:
+                        template_content = importlib.resources.read_text('blueprint_cli.templates', 'agent-file-template.md')
+                        console.print(f"[green]Debug:[/green] Found template using importlib.resources.read_text")
+                    except:
+                        # If the package resource is not found, try to find the template relative to this file
+                        current_file_dir = Path(__file__).parent.parent  # Should be src/blueprint_cli
+                        template_path_pkg = current_file_dir / "templates" / "agent-file-template.md"
+                        
+                        if template_path_pkg.exists():
+                            template_content = template_path_pkg.read_text(encoding='utf-8')
+                            console.print(f"[green]Debug:[/green] Found template in package relative path: {template_path_pkg}")
+                        else:
+                            # Final fallback - show what we're looking for and return with error
+                            error_msg = f"Agent template not found in any location: {agent_template_path}, package resources, or relative path {template_path_pkg}"
+                            if tracker:
+                                tracker.error(f"agent-md-{agent}", error_msg)
+                            else:
+                                console.print(f"[red]Error:[/red] {error_msg}")
+                            return
+            except Exception as inner_e:
+                console.print(f"[yellow]Debug:[/yellow] Could not use importlib.resources method: {inner_e}")
+                # Fallback to error
+                error_msg = f"Agent template not found: {agent_template_path}"
+                if tracker:
+                    tracker.error(f"agent-md-{agent}", error_msg)
+                else:
+                    console.print(f"[red]Error:[/red] {error_msg}")
+                return
 
         # Create agent-specific filename based on agent name
         # Map agent names to appropriate file names
@@ -567,6 +598,8 @@ def create_agent_specific_md_file(project_path: Path, agent: str, tracker: StepT
         if tracker:
             tracker.add(f"agent-md-{agent}", f"Create {filename} file")
             tracker.complete(f"agent-md-{agent}", f"Created {filename} in project root")
+        
+        console.print(f"[green]Debug:[/green] Successfully created {filename} in {project_path}")
 
     except Exception as e:
         error_msg = f"Error creating agent-specific MD file: {str(e)}"
@@ -574,6 +607,8 @@ def create_agent_specific_md_file(project_path: Path, agent: str, tracker: StepT
             tracker.error(f"agent-md-{agent}", error_msg)
         else:
             console.print(f"[red]Error:[/red] {error_msg}")
+        import traceback
+        traceback.print_exc()  # Print the full traceback for debugging
         raise  # Re-raise to ensure the error is properly handled by the main init function
 
 
